@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>MainWindow</name>
     <message>
@@ -8,27 +8,56 @@
         <translation>Assistant réseau - Network Assistant</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="70"/>
+        <location filename="mainwindow.ui" line="86"/>
+        <location filename="ui_mainwindow.h" line="799"/>
+        <source>About...</source>
+        <translation>À propos...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="109"/>
+        <location filename="ui_mainwindow.h" line="803"/>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="177"/>
+        <location filename="ui_mainwindow.h" line="805"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Quitter</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="184"/>
+        <location filename="ui_mainwindow.h" line="807"/>
+        <source>Alt+C</source>
+        <translation>Alt+C</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="219"/>
         <location filename="ui_mainwindow.h" line="770"/>
         <source>Status</source>
         <translation>Etat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="76"/>
+        <location filename="mainwindow.ui" line="225"/>
         <location filename="ui_mainwindow.h" line="757"/>
         <source>IP address</source>
         <translation>Adresse IP</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="112"/>
+        <location filename="mainwindow.ui" line="261"/>
         <location filename="ui_mainwindow.h" line="760"/>
         <source>Hardware detected</source>
         <translation>Matériel détecté</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="143"/>
-        <location filename="mainwindow.ui" line="389"/>
-        <location filename="mainwindow.ui" line="502"/>
+        <location filename="mainwindow.ui" line="280"/>
+        <source>Enable</source>
+        <translation>Activer</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="303"/>
+        <location filename="mainwindow.ui" line="593"/>
+        <location filename="mainwindow.ui" line="706"/>
         <location filename="ui_mainwindow.h" line="761"/>
         <location filename="ui_mainwindow.h" line="774"/>
         <location filename="ui_mainwindow.h" line="780"/>
@@ -36,485 +65,496 @@
         <translation>Rescanner</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="215"/>
+        <location filename="mainwindow.ui" line="372"/>
+        <source>Enabled</source>
+        <translation>Activé</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="377"/>
+        <source>Interface</source>
+        <translation>Interface</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="382"/>
+        <source>Driver</source>
+        <translation>Pilote</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="387"/>
+        <source>Description</source>
+        <translation>Description</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="392"/>
+        <source>Vendor</source>
+        <translation>Fournisseur</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="397"/>
+        <source>Product</source>
+        <translation>Produit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="405"/>
+        <source>Disable</source>
+        <translation>Désactiver</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="419"/>
         <location filename="ui_mainwindow.h" line="762"/>
         <source>Active interface</source>
         <translation>Interface active</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="231"/>
+        <location filename="mainwindow.ui" line="435"/>
         <location filename="ui_mainwindow.h" line="764"/>
         <source>WiFi status</source>
         <translation>Etat du WIFI</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="253"/>
+        <location filename="mainwindow.ui" line="457"/>
         <location filename="ui_mainwindow.h" line="767"/>
         <source>Unblocks all soft/hard blocked wireless devices</source>
         <translation>Débloquer tous les périphériques WiFi bloqués</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="256"/>
+        <location filename="mainwindow.ui" line="460"/>
         <location filename="ui_mainwindow.h" line="769"/>
         <source>Unblock WiFi Devices</source>
         <translation>Débloquer les périphériques WiFi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="288"/>
+        <location filename="mainwindow.ui" line="492"/>
         <location filename="ui_mainwindow.h" line="776"/>
         <source>Linux drivers</source>
         <translation>Pilotes Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="300"/>
+        <location filename="mainwindow.ui" line="504"/>
         <location filename="ui_mainwindow.h" line="771"/>
         <source>Associated Linux drivers</source>
         <translation>Pilotes Linux associés</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="309"/>
+        <location filename="mainwindow.ui" line="513"/>
         <location filename="ui_mainwindow.h" line="772"/>
         <source>Load Driver</source>
         <translation>Charger le pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="372"/>
+        <location filename="mainwindow.ui" line="576"/>
         <location filename="ui_mainwindow.h" line="773"/>
         <source>Unload Driver</source>
         <translation>Décharger le pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="409"/>
+        <location filename="mainwindow.ui" line="613"/>
+        <location filename="mainwindow.cpp" line="833"/>
         <location filename="ui_mainwindow.h" line="775"/>
         <source>Block Driver</source>
         <translation>Bloquer le pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="428"/>
+        <location filename="mainwindow.ui" line="632"/>
         <location filename="ui_mainwindow.h" line="785"/>
         <source>Windows drivers</source>
         <translation>Pilotes Windows</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="434"/>
+        <location filename="mainwindow.ui" line="638"/>
         <location filename="ui_mainwindow.h" line="777"/>
         <source>Available Windows drivers</source>
         <translation>Pilotes Windows disponibles</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="468"/>
+        <location filename="mainwindow.ui" line="672"/>
         <location filename="ui_mainwindow.h" line="778"/>
         <source>Remove Driver</source>
         <translation>Supprimer pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="479"/>
+        <location filename="mainwindow.ui" line="683"/>
         <location filename="ui_mainwindow.h" line="779"/>
         <source>Add Driver</source>
         <translation>Ajouter pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="520"/>
+        <location filename="mainwindow.ui" line="724"/>
         <location filename="ui_mainwindow.h" line="781"/>
         <source>About NDISwrapper</source>
         <translation>À propos de NDISwrapper</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="532"/>
+        <location filename="mainwindow.ui" line="736"/>
         <location filename="ui_mainwindow.h" line="782"/>
         <source>Install NDISwrapper</source>
         <translation>Installer NDISwrapper</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="543"/>
+        <location filename="mainwindow.ui" line="747"/>
         <location filename="ui_mainwindow.h" line="783"/>
         <source>In order to use Windows drivers you need first to install NDISwrapper</source>
         <translation>Pour pouvoir utiliser les pilotes Windows vous devez d’abord installer NDISwrapper</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="559"/>
+        <location filename="mainwindow.ui" line="763"/>
         <location filename="ui_mainwindow.h" line="784"/>
         <source>Uninstall NDISwrapper</source>
         <translation>Désinstaller NDISwrapper</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="591"/>
+        <location filename="mainwindow.ui" line="795"/>
         <location filename="ui_mainwindow.h" line="798"/>
         <source>Net diagnostics</source>
         <translation>Diagnostics réseau</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="603"/>
+        <location filename="mainwindow.ui" line="807"/>
         <location filename="ui_mainwindow.h" line="786"/>
         <source>Ping</source>
         <translation>Ping</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="609"/>
-        <location filename="mainwindow.ui" line="726"/>
+        <location filename="mainwindow.ui" line="813"/>
+        <location filename="mainwindow.ui" line="933"/>
         <location filename="ui_mainwindow.h" line="787"/>
         <location filename="ui_mainwindow.h" line="793"/>
         <source>Target URL:</source>
         <translation>URL cible :</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="619"/>
+        <location filename="mainwindow.ui" line="823"/>
         <location filename="ui_mainwindow.h" line="788"/>
         <source>Packets</source>
         <translation>Paquets</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="661"/>
-        <location filename="mainwindow.ui" line="781"/>
+        <location filename="mainwindow.ui" line="868"/>
+        <location filename="mainwindow.ui" line="991"/>
         <location filename="ui_mainwindow.h" line="789"/>
         <location filename="ui_mainwindow.h" line="795"/>
         <source>Start</source>
         <translation>Démarrer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="678"/>
-        <location filename="mainwindow.ui" line="798"/>
+        <location filename="mainwindow.ui" line="885"/>
+        <location filename="mainwindow.ui" line="1008"/>
         <location filename="ui_mainwindow.h" line="790"/>
         <location filename="ui_mainwindow.h" line="796"/>
         <source>Clear</source>
         <translation>Effacer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="692"/>
-        <location filename="mainwindow.ui" line="812"/>
+        <location filename="mainwindow.ui" line="899"/>
+        <location filename="mainwindow.ui" line="1022"/>
         <location filename="ui_mainwindow.h" line="791"/>
         <location filename="ui_mainwindow.h" line="797"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="720"/>
+        <location filename="mainwindow.ui" line="927"/>
         <location filename="ui_mainwindow.h" line="792"/>
         <source>Traceroute</source>
         <translation>Traceroute</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="736"/>
+        <location filename="mainwindow.ui" line="943"/>
         <location filename="ui_mainwindow.h" line="794"/>
         <source>Hops</source>
         <translation>Bonds</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="868"/>
-        <location filename="ui_mainwindow.h" line="799"/>
-        <source>About...</source>
-        <translation>À propos...</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="891"/>
-        <location filename="ui_mainwindow.h" line="803"/>
-        <source>Help</source>
-        <translation>Aide</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="959"/>
-        <location filename="ui_mainwindow.h" line="805"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Fermer</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="966"/>
-        <location filename="ui_mainwindow.h" line="807"/>
-        <source>Alt+C</source>
-        <translation>Alt+C</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="87"/>
+        <location filename="mainwindow.cpp" line="86"/>
         <source>IP address from router:</source>
         <translation>Adresse IP d’après le routeur :</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="88"/>
+        <location filename="mainwindow.cpp" line="87"/>
         <source>External IP address:</source>
         <translation>Adresse IP externe</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="196"/>
-        <location filename="mainwindow.cpp" line="210"/>
-        <location filename="mainwindow.cpp" line="224"/>
+        <location filename="mainwindow.cpp" line="124"/>
+        <location filename="mainwindow.cpp" line="137"/>
+        <source>Interface: %1</source>
+        <translation>Interface : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="124"/>
+        <location filename="mainwindow.cpp" line="138"/>
+        <source>Driver: %1</source>
+        <translation>Pilote : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="125"/>
+        <location filename="mainwindow.cpp" line="139"/>
+        <source>Description: %1</source>
+        <translation>Description : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="140"/>
+        <source>Product: %1</source>
+        <translation>Produit : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="141"/>
+        <source>Vendor: %1</source>
+        <translation>Fournisseur : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="127"/>
+        <location filename="mainwindow.cpp" line="142"/>
+        <source>Enabled: %1</source>
+        <translation>Activé : %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="195"/>
+        <location filename="mainwindow.cpp" line="209"/>
+        <location filename="mainwindow.cpp" line="223"/>
         <source>&amp;Copy</source>
         <translation>&amp;Copier</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="197"/>
+        <location filename="mainwindow.cpp" line="211"/>
+        <location filename="mainwindow.cpp" line="225"/>
+        <source>Ctrl+C</source>
+        <translation>Ctrl+C</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="198"/>
         <location filename="mainwindow.cpp" line="212"/>
         <location filename="mainwindow.cpp" line="226"/>
-        <source>Ctrl+C</source>
-        <translation>Ctrl+C</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="199"/>
-        <location filename="mainwindow.cpp" line="213"/>
-        <location filename="mainwindow.cpp" line="227"/>
         <source>Copy &amp;All</source>
         <translation>Copier &amp;Tout</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="201"/>
-        <location filename="mainwindow.cpp" line="215"/>
-        <location filename="mainwindow.cpp" line="229"/>
+        <location filename="mainwindow.cpp" line="200"/>
+        <location filename="mainwindow.cpp" line="214"/>
+        <location filename="mainwindow.cpp" line="228"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="261"/>
-        <location filename="mainwindow.cpp" line="278"/>
+        <location filename="mainwindow.cpp" line="260"/>
+        <location filename="mainwindow.cpp" line="277"/>
         <source>Traceroute not installed</source>
         <translation>Traceroute n’est pas installé</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="262"/>
+        <location filename="mainwindow.cpp" line="261"/>
         <source>Traceroute is not installed, do you want to install it now?</source>
         <translation>Traceroute n’est pas installé. Voulez-vous l’installer maintenant?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="269"/>
+        <location filename="mainwindow.cpp" line="267"/>
         <source>Traceroute hasn&apos;t been installed</source>
         <translation>Traceroute n’a pas été installé</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="270"/>
+        <location filename="mainwindow.cpp" line="268"/>
         <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
         <translation>Impossible d’installer Traceroute. Cela se produit si vous utilisez un Live CD ou si vous n’êtes pas en mesure d’accéder au dépôt logiciel.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="279"/>
+        <location filename="mainwindow.cpp" line="278"/>
         <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
         <translation>Traceroute n’est pas encore installé et son installation est impossible car aucune connexion à Internet n’a été détectée.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="285"/>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="mainwindow.cpp" line="330"/>
         <source>No destination host</source>
         <translation>Aucune destination hôte</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
-        <location filename="mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="285"/>
+        <location filename="mainwindow.cpp" line="330"/>
         <source>Please fill in the destination host field</source>
         <translation>Veuillez remplir le champs de la destination hôte</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="440"/>
+        <location filename="mainwindow.cpp" line="445"/>
         <source>Loaded Drivers</source>
         <translation>Pilotes chargés</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="449"/>
+        <location filename="mainwindow.cpp" line="454"/>
         <source>Unloaded Drivers</source>
         <translation>Pilotes déchargés</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="464"/>
+        <location filename="mainwindow.cpp" line="468"/>
         <source>Blocked Drivers</source>
         <translation>Pilotes bloqués</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="486"/>
+        <location filename="mainwindow.cpp" line="488"/>
         <source>Blocked Broadcom Drivers</source>
         <translation>Pilotes de Broadcom bloqués</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="894"/>
-        <source>enabled</source>
-        <translation>activé</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="897"/>
-        <source>disabled</source>
-        <translation>désactivé</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="900"/>
-        <source>WiFi hardware switch is off</source>
-        <translation>L’interrupteur physique du wifi est désactivé</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="908"/>
-        <source>Locate the Windows driver you want to add</source>
-        <translation>Trouvez le pilote Windows que vous désirez ajouter</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="908"/>
-        <source>Windows installation information file (*.inf)</source>
-        <translation>Fichier d’information pour installation Windows (*.inf)</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="939"/>
-        <source>*.sys file not found</source>
-        <translation>Fichier *.sys introuvable</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="939"/>
-        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation>Les fichiers *.sys doivent se trouver dans le même emplacement que le fichier *.inf. %1 introuvable.</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="948"/>
-        <source>sys file reference not found</source>
-        <translation>Impossible de trouver le fichier de référence sys</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="948"/>
-        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation>Apres analyse du fichier inf, il est impossible de déterminer le fichier sys du pilote donné</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="967"/>
-        <source>Ndiswrapper driver removed.</source>
-        <translation>Ndiswrapper a été supprimé.</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="975"/>
-        <source>%1 Help</source>
-        <translation>%1 Aide</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="1012"/>
-        <source>About %1</source>
-        <translation>À propos %1</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="1013"/>
-        <source>Version: </source>
-        <translation>Version : </translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="1014"/>
-        <source>Program for troubleshooting and configuring network for antiX Linux</source>
-        <translation>Programme permettant le dépannage et la configuration du réseau de antiX Linux</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="1016"/>
-        <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation>Copyright (c) MEPIS LLC et MX Linux</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="1017"/>
-        <source>%1 License</source>
-        <translation>%1 Licence</translation>
-    </message>
-</context>
-<context>
-    <name>QApplication</name>
-    <message>
-        <location filename="about.cpp" line="32"/>
-        <source>License</source>
-        <translation>Licence</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="33"/>
-        <location filename="about.cpp" line="43"/>
-        <source>Changelog</source>
-        <translation>Journal des modifications</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="34"/>
-        <source>Cancel</source>
-        <translation>Annuler</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="51"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Fermer</translation>
-    </message>
-    <message>
-        <location filename="main.cpp" line="44"/>
-        <source>You must run this program as root.</source>
-        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="509"/>
+        <location filename="mainwindow.cpp" line="510"/>
         <source>Ndiswrapper is not installed</source>
         <translation>NDISwrapper n’est pas installé</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="521"/>
+        <location filename="mainwindow.cpp" line="523"/>
         <source>driver installed</source>
         <translation>pilote installé</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="529"/>
+        <location filename="mainwindow.cpp" line="532"/>
         <source> and in use by </source>
         <translation>et utilisé par</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="536"/>
+        <location filename="mainwindow.cpp" line="539"/>
         <source>. Alternate driver: </source>
         <translation>. Pilote alternatif :</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="613"/>
+        <location filename="mainwindow.cpp" line="603"/>
         <source>Driver removed from blocklist</source>
         <translation>Pilote retiré de la liste de blocage</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="614"/>
+        <location filename="mainwindow.cpp" line="603"/>
         <source>Driver removed from blocklist.</source>
         <translation>Pilote retiré de la liste de blocage.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="620"/>
-        <location filename="mainwindow.cpp" line="621"/>
+        <location filename="mainwindow.cpp" line="609"/>
         <source>Module blocked</source>
         <translation>Module bloqué</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="786"/>
+        <location filename="mainwindow.cpp" line="763"/>
         <source>Installation successful</source>
         <translation>Installation réussie</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="789"/>
+        <location filename="mainwindow.cpp" line="765"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
         <translation>Erreur detectée, impossible de compiler le pilote ndiswrapper.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="792"/>
+        <location filename="mainwindow.cpp" line="768"/>
         <source>Error detected, could not install ndiswrapper.</source>
         <translation>Erreur détectée, impossible d’installer ndiswrapper.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="804"/>
+        <location filename="mainwindow.cpp" line="780"/>
         <source>Error encountered while removing Ndiswrapper</source>
         <translation>Une erreur s’est produite en supprimant ndiswrapper</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="855"/>
+        <location filename="mainwindow.cpp" line="830"/>
         <source>Unblock Driver</source>
         <translation>Débloquer le pilote</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="858"/>
-        <source>Block Driver</source>
-        <translation>Bloquer le pilote</translation>
+        <location filename="mainwindow.cpp" line="862"/>
+        <source>enabled</source>
+        <translation>activé</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="995"/>
+        <location filename="mainwindow.cpp" line="865"/>
+        <source>disabled</source>
+        <translation>désactivé</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="868"/>
+        <source>WiFi hardware switch is off</source>
+        <translation>L’interrupteur physique du wifi est désactivé</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="875"/>
+        <source>Locate the Windows driver you want to add</source>
+        <translation>Trouvez le pilote Windows que vous désirez ajouter</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="876"/>
+        <source>Windows installation information file (*.inf)</source>
+        <translation>Fichier d’information pour installation Windows (*.inf)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="907"/>
+        <source>*.sys file not found</source>
+        <translation>Fichier *.sys introuvable</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="908"/>
+        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
+        <translation>Les fichiers *.sys doivent se trouver dans le même emplacement que le fichier *.inf. %1 introuvable.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="919"/>
+        <source>sys file reference not found</source>
+        <translation>Impossible de trouver le fichier de référence sys</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="920"/>
+        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
+        <translation>Apres analyse du fichier inf, il est impossible de déterminer le fichier sys du pilote donné</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="937"/>
+        <source>Ndiswrapper driver removed.</source>
+        <translation>Ndiswrapper a été supprimé.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="945"/>
+        <source>%1 Help</source>
+        <translation>%1 Aide</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="957"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>Impossible de déverrouiller les périphériques.
 Il se peut que les périphériques Wi-Fi soient déjà déverrouillés.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="997"/>
+        <location filename="mainwindow.cpp" line="959"/>
         <source>WiFi devices unlocked.</source>
         <translation>Les périphériques Wi-Fi sont déverrouillés.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1040"/>
-        <location filename="mainwindow.cpp" line="1041"/>
+        <location filename="mainwindow.cpp" line="974"/>
+        <source>About %1</source>
+        <translation>À propos %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="975"/>
+        <source>Version: </source>
+        <translation>Version : </translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="976"/>
+        <source>Program for troubleshooting and configuring network for antiX Linux</source>
+        <translation>Programme permettant le dépannage et la configuration du réseau de antiX Linux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="978"/>
+        <source>Copyright (c) MEPIS LLC and MX Linux</source>
+        <translation>Copyright (c) MEPIS LLC et MX Linux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="979"/>
+        <source>%1 License</source>
+        <translation>%1 Licence</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1005"/>
         <source>Driver loaded successfully</source>
         <translation>Chargement du pilote accompli</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1056"/>
-        <location filename="mainwindow.cpp" line="1057"/>
+        <location filename="mainwindow.cpp" line="1020"/>
         <source>Driver unloaded successfully</source>
         <translation>Déchargement du pilote accompli</translation>
     </message>
@@ -522,12 +562,49 @@ Il se peut que les périphériques Wi-Fi soient déjà déverrouillés.</transla
 <context>
     <name>QObject</name>
     <message>
-        <location filename="mainwindow.cpp" line="638"/>
+        <location filename="about.cpp" line="52"/>
+        <source>License</source>
+        <translation>Licence</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="53"/>
+        <location filename="about.cpp" line="63"/>
+        <source>Changelog</source>
+        <translation>Journal des modifications</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="76"/>
+        <source>&amp;Close</source>
+        <translation>Q&amp;uitter</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="70"/>
+        <location filename="main.cpp" line="78"/>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="71"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur normal pour utiliser ce programme.</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="79"/>
+        <source>You must run this program with admin access.</source>
+        <translation>Vous devez exécuter ce programme avec un accès administrateur.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="624"/>
         <source>Could not load </source>
         <translation>Chargement impossible</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="669"/>
+        <location filename="mainwindow.cpp" line="649"/>
         <source>Could not unload </source>
         <translation>Déchargement impossible</translation>
     </message>
